pitcharraytools.PitchArrayCell
==============================

.. abjad-lineage:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell

.. autoclass:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.column_indices
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.indices
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.is_first_in_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.is_last_in_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.next
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.parent_array
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.parent_column
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.parent_row
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.prev
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.row_index
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.storage_format
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.token
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.weight
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.width
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.pitches
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.matches_cell
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__eq__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__ge__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__gt__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__le__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__lt__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__ne__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__repr__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell.PitchArrayCell.__str__
   :noindex:
